@@ -1,19 +1,7 @@
 /*
-    This file is part of kdev-python, the python language plugin for KDevelop
-    Copyright (C) 2012  Sven Brauch <svenbrauch@googlemail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "debugjob.h"
@@ -39,7 +27,8 @@ void DebugJob::start()
     QStringList program;
     QString debuggerUrl = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kdevpythonsupport/debugger", QStandardPaths::LocateDirectory) + "/kdevpdb.py";
     program << m_interpreter << "-u" << debuggerUrl << m_scriptUrl.toLocalFile() << m_args;
-    m_session = new DebugSession(program, m_workingDirectory);
+    // Inject environment
+    m_session = new DebugSession(program, m_workingDirectory, m_envProfileName);
     
     setStandardToolView(KDevelop::IOutputView::DebugView);
     setBehaviours(KDevelop::IOutputView::Behaviours(KDevelop::IOutputView::AllowUserClose) | KDevelop::IOutputView::AutoScroll);
@@ -104,3 +93,5 @@ DebugJob::~DebugJob()
 }
 
 }
+
+#include "moc_debugjob.cpp"
